"""Console script for justice."""
import argparse
import pprint
import sys

from justice.justice import Justice


def main():
    """Console script for justice."""
    pp = pprint.PrettyPrinter(indent=4)

    parser = argparse.ArgumentParser()
    parser.add_argument('-g', '--get', type=str, nargs='*')
    parser.add_argument('-s', '--search', type=str, nargs='+')
    args = parser.parse_args()

    if args.get:
        for subject in args.get:
            pp.pprint(Justice.get_detail(subject_id=subject))
    elif args.search:
        pp.pprint(Justice.search(string=' '.join(args.search)))
    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover



"""Main module."""
from pyquery import PyQuery as pq

from justice.parser import Parser


class Justice:
    SEARCH_URL = 'https://or.justice.cz/ias/ui/rejstrik?p::submit=x&\
-1.IFormSubmitListener-htmlContainer-top-form=&search={}'
    DETAIL_URL = 'https://or.justice.cz/ias/ui/rejstrik-firma.vysledky?subjektId={}&typ={}'
    DETAIL_TYPE_MAPPING = {'FULL': 'UPLNY', 'VALID': 'PLATNY'}

    def __init__(self, *, search_url=SEARCH_URL, detail_url=DETAIL_URL):
        self.SEARCH_URL = search_url
        self.DETAIL_URL = detail_url

    @classmethod
    def search(cls, string: str):
        doc = pq(url=cls.SEARCH_URL.format(string))
        return Parser.parse_list_result(doc)

    @classmethod
    def get_detail(cls, subject_id: str, typ: str = "FULL"):
        """
        :param subject_id: ID of subject
        :param typ: FULL/VALID
        :return:
        """
        assert typ in cls.DETAIL_TYPE_MAPPING, f"""`typ` has to be one of {[cls.DETAIL_TYPE_MAPPING.keys()]}.
        Not {typ}"""
        assert type(subject_id) == str, f"""`subject_id` has to be string, not {type(subject_id)}"""

        doc = pq(url=cls.DETAIL_URL.format(subject_id, cls.DETAIL_TYPE_MAPPING[typ]))
        return Parser.parse_detail_result(doc)


if __name__ == '__main__':
    justice = Justice()
    # print(justice.search('08431116'))
    # print(justice.search('Seznam'))

    print(justice.get_detail('1060090'))
    print(justice.get_detail('676708'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from urllib.parse import urlparse, parse_qs

from pyquery import PyQuery as pq

from justice.parser import line_parser


class Parser:
    @staticmethod
    def parse_list_result(docs: pq):
        result = []
        for doc in docs('li.result'):
            result.append(Parser.parse_list_one(doc))
        return result

    @staticmethod
    def parse_list_one(doc: pq):
        doc = pq(doc)
        keys = ('name', 'ico', 'file_number', 'registration_date', 'resistance')
        result = {}
        for pos, table_data in enumerate(doc.find('table tbody tr td')):
            result[keys[pos]] = pq(table_data).text()
        subject_id = ''
        for link in doc.find('.result-links li a'):
            href = link.attrib['href']
            parsed_href = urlparse(href)
            parsed_query = parse_qs(parsed_href.query)
            if 'subjektId' in parsed_query:
                subject_id, = parsed_query['subjektId']
                break
        if subject_id:
            result['subject_id'] = subject_id
        return result

    @staticmethod
    def parse_detail_result(doc: pq):
        result = []
        doc = pq(doc.find(".section-c .aunp-content .div-row"))
        for table_row in doc:
            line = []
            for div_cell in pq(table_row).find('.div-cell'):
                line.append(pq(div_cell).text())
            result.append(line)
        parsed_result = []
        parser = line_parser.EmptyLineParser
        parser_key = ''
        for line in result:
            key = line[0]
            if key in line_parser.detail_parser_mapping:
                parser_key = key
                parser = line_parser.detail_parser_mapping[key]
            if len(line) >= 2:
                value, expired = parser().parse(data=line[1:])
                if value:
                    parsed_result.append((parser_key, value, expired))
        return parsed_result



from justice.parser.line_parser import AbstractLineParser


class EmptyLineParser(AbstractLineParser):
    def parse_data(self, data):
        pass

    @staticmethod
    def parse_date(data: str):
        pass



from justice.parser.line_parser.abc import AbstractLineParser
from justice.parser.line_parser.company_name import CompanyNameParser
from justice.parser.line_parser.empty import EmptyLineParser

detail_parser_mapping = {
    'Obchodní firma:': CompanyNameParser,
    'Sídlo:': EmptyLineParser,
}


__all__ = (
    'AbstractLineParser',
    'CompanyNameParser',
    'EmptyLineParser',

    'detail_parser_mapping',
)



import abc
import dateparser


class AbstractLineParser:
    def parse(self, data):
        parsed_date = None
        parsed_data = self.parse_data(data[0])
        if len(data) > 1:
            parsed_date = self.parse_date(data[1])
        return parsed_data, parsed_date

    @abc.abstractmethod
    def parse_data(self, data):
        pass

    @staticmethod
    def parse_date(data: str):
        result = {}
        expire = data.split('\n')
        expire_from = expire[0].replace('zapsáno\xa0', '')
        result['valid_from'] = dateparser.parse(expire_from)
        if len(expire) == 2:
            expire_to = expire[1].replace('vymazáno\xa0', '')
            result['valid_to'] = dateparser.parse(expire_to)
        return result
